==> orthanc_0.7.2.orig.tar.gz: Orthanc-0.7.2/OrthancServer/DicomProtocol/IApplicationEntityFilter.h <==
/**
 * Orthanc - A Lightweight, RESTful DICOM Store
 * Copyright (C) 2012-2013 Medical Physics Department, CHU of Liege,
 * Belgium
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * In addition, as a special exception, the copyright holders of this
 * program give permission to link the code of its release with the
 * OpenSSL project's "OpenSSL" library (or with modified versions of it
 * that use the same license as the "OpenSSL" library), and distribute
 * the linked executables. You must obey the GNU General Public License
 * in all respects for all of the code used other than "OpenSSL". If you
 * modify file(s) with this exception, you may extend this exception to
 * your version of the file(s), but you are not obligated to do so. If
 * you do not wish to do so, delete this exception statement from your
 * version. If you delete this exception statement from all source files
 * in the program, then also delete it here.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 **/


#pragma once

#include "../ServerEnumerations.h"

#include <string>

namespace Orthanc
{
  class IApplicationEntityFilter
  {
  public:
    virtual ~IApplicationEntityFilter()
    {
    }

    virtual bool IsAllowedConnection(const std::string& callingIp,
                                     const std::string& callingAet) = 0;

    virtual bool IsAllowedRequest(const std::string& callingIp,
                                  const std::string& callingAet,
                                  DicomRequestType type) = 0;
  };
}

==> orthanc_1.0.0+dfsg.orig.tar.gz: Orthanc-1.0.0/OrthancServer/DicomProtocol/IApplicationEntityFilter.h <==
/**
 * Orthanc - A Lightweight, RESTful DICOM Store
 * Copyright (C) 2012-2015 Sebastien Jodogne, Medical Physics
 * Department, University Hospital of Liege, Belgium
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * In addition, as a special exception, the copyright holders of this
 * program give permission to link the code of its release with the
 * OpenSSL project's "OpenSSL" library (or with modified versions of it
 * that use the same license as the "OpenSSL" library), and distribute
 * the linked executables. You must obey the GNU General Public License
 * in all respects for all of the code used other than "OpenSSL". If you
 * modify file(s) with this exception, you may extend this exception to
 * your version of the file(s), but you are not obligated to do so. If
 * you do not wish to do so, delete this exception statement from your
 * version. If you delete this exception statement from all source files
 * in the program, then also delete it here.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 **/


#pragma once

#include "../ServerEnumerations.h"

#include <string>

namespace Orthanc
{
  class IApplicationEntityFilter : public boost::noncopyable
  {
  public:
    virtual ~IApplicationEntityFilter()
    {
    }

    virtual bool IsAllowedConnection(const std::string& remoteIp,
                                     const std::string& remoteAet,
                                     const std::string& calledAet) = 0;

    virtual bool IsAllowedRequest(const std::string& remoteIp,
                                  const std::string& remoteAet,
                                  const std::string& calledAet,
                                  DicomRequestType type) = 0;

    virtual bool IsAllowedTransferSyntax(const std::string& remoteIp,
                                         const std::string& remoteAet,
                                         const std::string& calledAet,
                                         TransferSyntax syntax) = 0;

    virtual bool IsUnknownSopClassAccepted(const std::string& remoteIp,
                                           const std::string& remoteAet,
                                           const std::string& calledAet) = 0;
  };
}
